"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const practical_logger_core_1 = require("@offirmo/practical-logger-core");
const firefox_1 = tslib_1.__importDefault(require("./sinks/advanced/firefox"));
exports.sink_firefox = firefox_1.default;
const chromium_1 = tslib_1.__importDefault(require("./sinks/advanced/chromium"));
exports.sink_chromium = chromium_1.default;
const safari_1 = tslib_1.__importDefault(require("./sinks/advanced/safari"));
exports.sink_safari = safari_1.default;
const advanced_1 = require("./sinks/advanced");
function getLogLevelLocalStorageKeyForLogger(name) {
    return `_debug.logger.${name}.level`;
}
function getLevelFromAboveForLogger(name) {
    let logLevel = null;
    try {
        const LSKey = getLogLevelLocalStorageKeyForLogger(name);
        logLevel = localStorage.getItem(LSKey);
        try {
            if (logLevel)
                practical_logger_core_1.checkLevel(logLevel);
            else
                logLevel = null;
        }
        catch (_a) {
            logLevel = practical_logger_core_1.DEFAULT_LOG_LEVEL;
            localStorage.setItem(LSKey, logLevel);
        }
        //console.log({name, LSKey, logLevel})
    }
    catch ( /* ignore */_b) { /* ignore */ }
    return logLevel;
}
function createLogger(p) {
    const { name = practical_logger_core_1.DEFAULT_LOGGER_KEY } = p;
    const sink = p.sink || advanced_1.create();
    const logger = practical_logger_core_1.createLogger(p, sink);
    const logLevelFromAbove = getLevelFromAboveForLogger(name);
    if (logLevelFromAbove) {
        logger.setLevel(logLevelFromAbove);
    }
    return logger;
}
exports.createLogger = createLogger;
//# sourceMappingURL=index.js.map