import { createLogger as createLoggerCore, DEFAULT_LOGGER_KEY, DEFAULT_LOG_LEVEL, checkLevel } from '@offirmo/practical-logger-core';
import sink_firefox from './sinks/advanced/firefox';
import sink_chromium from './sinks/advanced/chromium';
import sink_safari from './sinks/advanced/safari';
import { create } from './sinks/advanced';
function getLogLevelLocalStorageKeyForLogger(name) {
    return `_debug.logger.${name}.level`;
}
function getLevelFromAboveForLogger(name) {
    let logLevel = null;
    try {
        const LSKey = getLogLevelLocalStorageKeyForLogger(name);
        logLevel = localStorage.getItem(LSKey);
        try {
            if (logLevel)
                checkLevel(logLevel);
            else
                logLevel = null;
        }
        catch (_a) {
            logLevel = DEFAULT_LOG_LEVEL;
            localStorage.setItem(LSKey, logLevel);
        }
        //console.log({name, LSKey, logLevel})
    }
    catch ( /* ignore */_b) { /* ignore */ }
    return logLevel;
}
function createLogger(p) {
    const { name = DEFAULT_LOGGER_KEY } = p;
    const sink = p.sink || create();
    const logger = createLoggerCore(p, sink);
    const logLevelFromAbove = getLevelFromAboveForLogger(name);
    if (logLevelFromAbove) {
        logger.setLevel(logLevelFromAbove);
    }
    return logger;
}
export { createLogger, sink_firefox, sink_chromium, sink_safari, };
//# sourceMappingURL=index.js.map